@@ -27,7 +27,7 @@ class MySql:
         try:
             await self.SaEngine()
             async with self.engine.acquire() as conn:
-                logging.debug(type(query))
+                # logging.debug(type(query))
                 if isinstance(query, list):
                     result = []
                     for i in query:
@@ -35,9 +35,10 @@ class MySql:
                             result.append(await (await conn.execute(i)).fetchall())
                         elif isinstance(i, sa.sql.dml.Insert) or isinstance(i, sa.sql.dml.Delete):
                             await conn.execute(i)
+                            await conn.execute("commit")
                         elif isinstance(i, str):
                             await conn.execute(i)
-                    await conn.execute("commit")
+                            await conn.execute("commit")
                     return result
                 elif isinstance(query, sa.sql.dml.Insert) or isinstance(query, sa.sql.dml.Delete):
                     await conn.execute(query)
